==> pybytom-1.2.2.tar.gz: pybytom-1.2.2/pybytom/script/builder.py <==
#!/usr/bin/env python3

from struct import pack
from binascii import unhexlify

from .opcode import (
    OP_0, OP_1, OP_DATA_1, OP_PUSHDATA1, OP_PUSHDATA2, OP_PUSHDATA4
)


class Builder:

    def __init__(self):
        self.program = bytearray()

    def add_op(self, op: int):
        self.program.append(op)
        return self

    def add_bytes(self, data: bytes):
        len_byte = len(data)

        if len_byte == 0:
            self.program.append(OP_0)
        elif len_byte <= 75:
            self.program.append(
                OP_DATA_1 + len_byte - 1
            )
            self.program += data
        elif len_byte < 1 << 8:
            self.program.append(OP_PUSHDATA1)
            self.program.append(len_byte)
            self.program += data
        elif len_byte < 1 << 16:
            self.program.append(OP_PUSHDATA2)
            self.program += pack("<H", len_byte)
            self.program += data
        else:
            self.program.append(OP_PUSHDATA4)
            self.program += pack("<L", len_byte)
            self.program += data
        return self

    def add_int(self, number: int):
        if number == 0:
            self.program.append(OP_0)
            return self
        if 1 <= number <= 16:
            self.program.append(
                OP_1 + number - 1
            )
            return self
        return self.add_bytes(bytes(number))
    
    def add_raw_bytes(self, data: str):
        self.program.append(
            unhexlify(data)
        )
        return self

    def digest(self):
        return self.program

    def hex_digest(self):
        return self.program.hex()

==> pybytom-1.3.0.tar.gz: pybytom-1.3.0/pybytom/script/builder.py <==
#!/usr/bin/env python3

from struct import pack
from binascii import unhexlify

from .opcode import (
    OP_0, OP_1, OP_DATA_1, OP_PUSHDATA1, OP_PUSHDATA2, OP_PUSHDATA4
)


class Builder:

    def __init__(self):
        self.program = bytearray()

    def add_op(self, op: int):
        self.program.append(op)
        return self

    def add_bytes(self, data: bytes):
        len_byte = len(data)

        if len_byte == 0:
            self.program.append(OP_0)
        elif len_byte <= 75:
            self.program.append(
                OP_DATA_1 + len_byte - 1
            )
            self.program += data
        elif len_byte < 1 << 8:
            self.program.append(OP_PUSHDATA1)
            self.program.append(len_byte)
            self.program += data
        elif len_byte < 1 << 16:
            self.program.append(OP_PUSHDATA2)
            self.program += pack("<H", len_byte)
            self.program += data
        else:
            self.program.append(OP_PUSHDATA4)
            self.program += pack("<L", len_byte)
            self.program += data
        return self

    def add_int(self, number: int):
        if number == 0:
            self.program.append(OP_0)
            return self
        if 1 <= number <= 16:
            self.program.append(
                OP_1 + number - 1
            )
            return self
        return self.add_bytes(number.to_bytes(
            8, byteorder="big", signed=True))
    
    def add_raw_bytes(self, data: str):
        self.program.append(
            unhexlify(data)
        )
        return self

    def digest(self):
        return self.program

    def hex_digest(self):
        return self.program.hex()
